using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using DataLayer;

public partial class blog : System.Web.UI.Page
{
    public enum eBlogAction
    {
        GetByID = 0,
        GetByTag = 1,
        GetByDate = 2,
        DefaultAction = -1
    }

    private int _BlogEntryID = -1;
    public int BlogEntryID
    {
        get
        {
            return _BlogEntryID;
        }
        set
        {
            _BlogEntryID = value;
        }
    }

    private string _BlogEntryTag = "";
    public string BlogEntryTag
    {
        get
        {
            return _BlogEntryTag;
        }
        set
        {
            _BlogEntryTag = value;
        }
    }

    private sBlogEntryDate _BlogEntryDate;
    public sBlogEntryDate BlogEntryDate
    {
        get
        {
            return _BlogEntryDate;
        }
        set
        {
            _BlogEntryDate = value;
        }
    }

    private PagedDataSource _PDS = new PagedDataSource();
    internal PagedDataSource PDS
    {
        get
        {
            return _PDS;
        }
        set
        {
            _PDS = value;
        }
    }

    private DataView _dvData;
    internal DataView dvData
    {
        get
        {
            return _dvData;
        }
        set
        {
            _dvData = value;
        }
    }

    private void SaveVars()
    {
        Page.Items.Add("Data", dvData);
        Page.Items.Add("CurrentPage", CurrentPage);
    }

    private void ReadVars()
    {
        if(Page.Items.Contains("Data"))
        {
            dvData = (DataView)Page.Items["Data"];
        }

        if (Page.Items.Contains("CurrentPage"))
        {
            CurrentPage = (int)Page.Items["CurrentPage"];
        }
    }

    private int _CurrentPage;
    internal int CurrentPage
    {
        get
        {
            return _CurrentPage;
        }
        set
        {
            _CurrentPage = value;
        }
    }

    private BlogDL _blogDL;
    internal BlogDL blogDL
    {
        get
        {
            return _blogDL;
        }
        set
        {
            _blogDL = value;
        }
    }

    private void SetPage()
    {
        PDS.CurrentPageIndex = CurrentPage;
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        try
        {
            if (!IsPostBack)
            {

                if (Request.QueryString.Count > 0)
                {
                    eBlogAction blogAction = CheckKey(Request.QueryString);

                    switch (blogAction)
                    {
                        case eBlogAction.GetByID:
                            GetBlogByID();
                            break;
                        case eBlogAction.GetByTag:
                            GetBlogByTag();
                            break;
                        case eBlogAction.GetByDate:
                            GetBlogByDate();
                            break;
                        case eBlogAction.DefaultAction:
                            //anything else we simply transfer back to the blogs
                            Server.Transfer("blog.aspx");
                            break;
                        default:
                            //anything unhandled previously we simply transfer back to the blogs
                            //not the error pages (for now)
                            Server.Transfer("blog.aspx");
                            break;
                    }
                }
            }
            
        }
        catch (Exception ex)
        {
             //log the error
             using (ErrorLogger el = new DataLayer.ErrorLogger(ex, ConfigurationManager.ConnectionStrings["DbConnection"].ConnectionString)) ;
             Response.Redirect("error.aspx", true);
        }
    }

  

    private void GetBlogByDate()
    {
        BlogEntryDate = sBlogEntryDate.CreateFromQuery(Request.Params["date"]);
        
        Session.Add("SingleBlogEntryDate", BlogEntryDate);
    }

    private eBlogAction CheckKey(System.Collections.Specialized.NameValueCollection queryString)
    {
        foreach (string s in queryString.AllKeys)
        {
            if (s == "tag")
            {
                return eBlogAction.GetByTag;
            }
            else if (s == "id")
            {
                return eBlogAction.GetByID;
            }
            else if (s == "date")
            {
                return eBlogAction.GetByDate;
            }
        }

        return eBlogAction.DefaultAction;
    }

    private void GetBlogByTag()
    {
        BlogEntryTag = Request.Params["tag"];

        Session.Add("SingleBlogEntryTag", BlogEntryTag);
    }

    private void GetBlogByID()
    {
        BlogEntryID = int.Parse(Request.Params["id"]);

        //double check that the ID is greater than 0;
        if (BlogEntryID < 1)
        {
            Server.Transfer("error.aspx", false);
        }

        Session.Add("SingleBlogEntryID", BlogEntryID);

    }


}


