using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using DataLayer;

public partial class controls_blogEntries : System.Web.UI.UserControl
{
    private GetBlogEntryByType _Gbebt;
    internal GetBlogEntryByType Gbebt
    {
        get
        {
            return _Gbebt;
        }
        set
        {
            _Gbebt = value;
        }
    }

    private bool _IsNextVisible = false;
    internal bool IsNextVisible
    {
        get
        {
            return _IsNextVisible;
        }
        set
        {
            _IsNextVisible = value;
        }
    }

    private bool _IsPrevVisible = false;
    internal bool IsPrevVisible
    {
        get
        {
            return _IsPrevVisible;
        }
        set
        {
            _IsPrevVisible = value;
        }
    }

    private BlogDL _BlogDataLayer = new BlogDL(ConfigurationManager.ConnectionStrings["DbConnection"].ConnectionString);
    internal BlogDL BlogDataLayer
    {
        get
        {
            return _BlogDataLayer;
        }
    
    }

    private PagedDataSource _PDS = new PagedDataSource();
    internal PagedDataSource PDS
    {
        get
        {
            return _PDS;
        }
        set
        {
            _PDS = value;
        }
    }

    private DataView _PagingSource = new DataView();
    internal DataView PagingSource
    {
        get
        {
            return _PagingSource;
        }
        set
        {
            _PagingSource = value;
        }
    }

    private int _CurrentPage = 0;
    internal int CurrentPage
    {
        get
        {
            return _CurrentPage;
        }
        set
        {
            _CurrentPage = value;
        }
    }

   
    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);

        ReadVars();
    }

    protected override void OnUnload(EventArgs e)
    {
        SaveVars();
        base.OnUnload(e);
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        RegisterHandlers();

        if (!Page.IsPostBack)
        {       
            try
            {
                if (Request.QueryString.Count == 0)
                {
                    //retrieve the last 5 blog entries
                    rptBlog.DataSource = BlogDataLayer.GetLatest5Entries();
                    rptBlog.DataBind();
                }
                else
                {
                    CheckBlogEntryType();
                }
            }
            catch (Exception ex)
            {
                Response.Redirect("error.aspx");
            }
        }
        else
        {
            BindData();
            SetupPDS();
            BindRepeater();
            SetRepeaterPage();
        }

        SetButtonVisibility();
    }

    private void BindData()
    {
        if (PagingSource != null)
        {
            PDS.DataSource = PagingSource;
        }
    }

    private void BindRepeater()
    {
        if (PDS.DataSource != null)
        {
            rptBlog.DataSource = PDS;
            rptBlog.DataBind();
        }
    }

    private void SetRepeaterPage()
    {
        if (PDS.DataSource != null && PDS.IsPagingEnabled)
        {
            PDS.CurrentPageIndex = this.CurrentPage;
        }
    }

    private void SetButtonVisibility()
    {
        if (PDS.PageCount > 1)
        {
            if (!PDS.IsLastPage)
            {
                IsNextVisible = true;
            }
            else
            {
                IsNextVisible = false;
            }

            if (!PDS.IsFirstPage)
            {
                IsPrevVisible = true;
            }
            else
            {
                IsPrevVisible = false;
            }
        }

        rptNext.Visible = IsNextVisible;
        rptPrev.Visible = IsPrevVisible;
    }

    private void CheckBlogEntryType()
    {
        if (!IsPostBack)
        {
            
            if (Session["SingleBlogEntryID"] != null || Session["SingleBlogEntryTag"] != null || Session["SingleBlogEntryDate"] != null)
            {
                if (Session["SingleBlogEntryID"] != null)
                {
                    Gbebt = GetBlogEntryByType.ID;
                }
                else if( Session["SingleBlogEntryTag"] != null)
                {
                    Gbebt = GetBlogEntryByType.TagCategory;
                }
                else if (Session["SingleBlogEntryDate"] != null)
                {
                    Gbebt = GetBlogEntryByType.Date;
                }
                GetBlogData(Gbebt);
            }
        }
        else
        {
            GetBlogData(Gbebt);
        }
    }

    private void GetBlogData(GetBlogEntryByType gbebt)
    {
        switch (gbebt)
        {
            case GetBlogEntryByType.Date:
                sBlogEntryDate sbed = (sBlogEntryDate)Session["SingleBlogEntryDate"];
                PagingSource = BlogDataLayer.EntriesByDate(sbed.StartDate, sbed.EndDate).DefaultView;
                break;
            case GetBlogEntryByType.ID:
                if (Session["SingleBlogEntryID"] != null)
                {
                    //retrieve the blog entry by ID
                    PagingSource = BlogDataLayer.GetSingleEntry(int.Parse(Session["SingleBlogEntryID"].ToString())).DefaultView;
                }
                break;
            case GetBlogEntryByType.TagCategory:
                if (Session["SingleBlogEntryTag"] != null)
                {
                    //retrieve the blog entry by Tag
                    PagingSource = BlogDataLayer.EntriesByTag(Session["SingleBlogEntryTag"].ToString()).DefaultView;
                }
                break;
            default:
                throw new Exception(string.Format("WTF? gbebt:{0}", gbebt));
        }


        SetupPDS();
        BindRepeater();
    }

    private void SetupPDS()
    {
        PDS.DataSource = PagingSource;
        PDS.PageSize = 10;
        PDS.AllowPaging = true;

        PDS.CurrentPageIndex = this.CurrentPage;
    }

    private void SaveVars()
    {
        //save Gbebt
        Session.Add("Gbebt", Gbebt);

        //save IsNextVisible
        Session.Add("IsNextVisible", IsNextVisible);

        //save IsPrevVisible
        Session.Add("IsPrevVisible", IsPrevVisible);

        //save the data into the Session
        Session.Add("PageableData", PagingSource);

        //save the CurrentPage index
        Session.Add("CurrentPage", CurrentPage);
    }

    private void ReadVars()
    {
        //read the postback variables
        if (IsPostBack)
        {
            //read Gbebt
            Gbebt = (GetBlogEntryByType)Session["Gbebt"];
            IsNextVisible = (bool)Session["IsNextVisible"];
            IsPrevVisible = (bool)Session["IsPrevVisible"];
            PagingSource = (DataView)Session["PageableData"];
            CurrentPage = (int)Session["CurrentPage"];
        }
        else//read the non-postback variables
        {
            //so far none
        }

        //all the other variables
        //so far none
    }

    private void RegisterHandlers()
    {
        rptBlog.ItemDataBound += new RepeaterItemEventHandler(rptBlog_ItemDataBound);
        rptNext.Click += new EventHandler(rptNext_Click);
        rptPrev.Click += new EventHandler(rptPrev_Click);
    }

    void rptPrev_Click(object sender, EventArgs e)
    {
        //check if the page is at the lower bound
        if (!PDS.IsFirstPage)
        {

            //decrement the current page value
            CurrentPage--;
        }

        SetRepeaterPage();
        SetButtonVisibility();

        SetupPDS();
        BindData();
        BindRepeater();
    }

    void rptNext_Click(object sender, EventArgs e)
    {
        //check if the page is at the upper bound
        if (!PDS.IsLastPage)
        {

            //increment the current page value
            CurrentPage++;
        }

        SetRepeaterPage();
        SetButtonVisibility();

        SetupPDS();
        BindData();
        BindRepeater();
    }

    private void rptBlog_ItemDataBound(object sender, RepeaterItemEventArgs e)
    {
        if(e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem)
        {
        
            //pass the values from (DataRowView)e.Item.DataItem[];
            controls_blogEntry cbe = (controls_blogEntry)e.Item.FindControl("ItemBlogEntryItem");
            DsBlog.tblBlogEntryRow ber = (DsBlog.tblBlogEntryRow)((DataRowView)e.Item.DataItem).Row ;
            

            if (ber != null)
            {
                cbe.BlogEntryID = ber.BlogEntryID;
                cbe.BlogEntryTitle = ber.BlogTitle;
                cbe.BlogEntrySubTitle = ber.BlogSubTitle;
                cbe.BlogEntryData = string.Format("<div>{0}</div><br />", ber.BlogEntry);
                string link = string.Format("http://www.mustafacodes.net/blog.aspx?id={0}",cbe.BlogEntryID);
                cbe.PermaLink = string.Format("<div class=\"blogEntryPermalinkRow\">permalink: <a href=\"{0}\">{0}</a></div>", link);
                cbe.BlogEntryFooter = ber.BlogDate.ToLongDateString();

                string s = ber.Tags;
                if(s.Length > 0)
                {
                    cbe.Tags = s.Substring(1);
                }
                else
                {
                    cbe.Tags = s;
                }
            }

        
        }
        
    }
 
}
